<?php


namespace OrganizationsManagement\Controller;

use OrganizationsManagement\Traits\TResponse;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use OrganizationsManagement\Util\Utilities;
use OrganizationsManagement\Util\InstanceProvider;


class Cliente
{
    use TResponse;

    public function findAllClientes(DTO\Request $request, DTO\Response $response){
        try {
            $data = InstanceProvider::getService()->getCliente()->findAllClientes();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function findAllVersions(DTO\Request $request, DTO\Response $response){
        try {
            $data = InstanceProvider::getService()->getCliente()->findAllVersions();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function findClientesWithLatestVersion(DTO\Request $request, DTO\Response $response){
        try {
            $data = InstanceProvider::getService()->getCliente()->findClientesWithLatestVersion();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function findVersionByCliente(DTO\Request $request, DTO\Response $response){
        try {
            $cdcliente = $request->getParameter('CDCLIENTE');
            $data = InstanceProvider::getService()->getCliente()->findVersionByCliente($cdcliente);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findClientesPorOperador(DTO\Request $request, DTO\Response $response)
    {
        try{
            $cdOperador = $request->getParameter('CDOPERADOR');
            $data = InstanceProvider::getService()->getCliente()->findClientesPorOperador($cdOperador);
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findRelacionarClientesComOperador(DTO\Request $request, DTO\Response $response)
    {
        try {
            $cdoperador = $request->getParameter('CDOPERADOR');
            $operators = InstanceProvider::getService()->getCliente()->findRelacionarClientesComOperador($cdoperador);
            $this->sendResponse($operators, 200);
        } catch (\Exception $ex){
            $response->setError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveRelacionarClientesComOperador(DTO\Request $request, DTO\Response $response)
    {
        try {
            $clienteService = InstanceProvider::getService()->getCliente();
            $clientes = $request->getParameter('clientes');
            $cdoperador = $request->getParameter('cdoperador');
            $idtpoperclie = $request->getParameter('idtpoperclie');
            $nrpriopercli = $request->getParameter('nrpriopercli');
            $clienteService->saveRelacionarClientesComOperador($clientes, $cdoperador, $idtpoperclie, $nrpriopercli);
        } catch (\Exception $ex){
            $response->setCriticalError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function deleteRelacionarClientesComOperador(DTO\Request $request, DTO\Response $response)
    {
        try {
            $clienteService = InstanceProvider::getService()->getCliente();
            $clientes = $request->getParameters();
            $clienteService->deleteRelacionarClientesComOperador($clientes);
        } catch (\Exception $ex) {
            $response->setCriticalError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }
    
    public function deleteAllVersionByCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
            $cdclientes = $request->getParameter('cdcliente');
            $data = InstanceProvider::getService()->getCliente()->deleteAllVersionByCliente($cdclientes);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function includeVersionsForClients(DTO\Request $request, DTO\Response $response){
        try {
            $nrversaodisp = $request->getParameter('nrversaodisps');
            $cdcliente = $request->getParameter('cdclientes');
            $data = InstanceProvider::getService()->getCliente()->includeVersionsForClients($nrversaodisp, $cdcliente);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function includeVersionsForAllClients(DTO\Request $request, DTO\Response $response){
        try {
            $nrversaodisp = $request->getParameter('nrversaodisps');
            $data = InstanceProvider::getService()->getCliente()->includeVersionsForAllClients($nrversaodisp);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
     public function deleteVersionsForClients(DTO\Request $request, DTO\Response $response){
        try {
            $nrversaodisp = $request->getParameter('nrversaodisps');
            $cdcliente = $request->getParameter('cdclientes');
            $data = InstanceProvider::getService()->getCliente()->deleteVersionsForClients($nrversaodisp, $cdcliente);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function deleteVersionsForAllClients(DTO\Request $request, DTO\Response $response){
        try {
            $nrversaodisp = $request->getParameter('nrversaodisps');
            $data = InstanceProvider::getService()->getCliente()->deleteVersionsForAllClients($nrversaodisp);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
