<?php

namespace OrganizationsManagement\Service;

use Exception;
use OrganizationsManagement\Util\Utilities;
use OrganizationsManagement\Util\InstanceProvider;
use Doctrine\ORM\EntityManager;

class SlaclienteAlert
{
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * SlaclienteParam constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function findSlaclienteAlert($cdcliente, $cdgrupfase, $cdassunto, $cdcomplexid): array
    {
        return InstanceProvider::getRepository()->getSlaclienteAlert()->findSlaclienteAlert($cdcliente, $cdgrupfase, $cdassunto, $cdcomplexid);
    }

    /**
     * @return array
     */
    public function findStructureType(): array
    {
        $orgaznizationId = InstanceProvider::getLibEnvironment()->getCurrentOrganizationId();
        return InstanceProvider::getRepository()->getStructureType()->findStructureType($orgaznizationId);
    }

    /**
     * @param $rows
     * @throws Exception
     */
    public function updateSlaclienteAlert($rows)
    {
        $slaclienteAlertRepository = InstanceProvider::getRepository()->getSlaclienteAlert();
        $slaclienteAlertFactory = InstanceProvider::getFactory()->getSlaclienteAlert();
        try {
            foreach ($rows as $row) {
                /** @var \Teknisa\Model\Teknisa\Entities\SlaclienteAlert $slaclienteAlert */
                $slaclienteAlert = $slaclienteAlertRepository->find($row['ID']);
                $slaclienteAlert = $slaclienteAlertFactory->update($slaclienteAlert, $row['ID_RESP_PROD_ESTRUT'],
                                                                   $row['STRUCTURE_TYPE_ID'], $row['QTHORASALERT'],
                                                                   $row['IDANTESDEPOIS'], 'S');
                $this->entityManager->persist($slaclienteAlert);
            }
            $this->entityManager->flush();
        } catch(Exception $e) {
            throw new Exception($e->getMessage());
        }
    }

    /**
     * @param $rows
     * @throws Exception
     */
    public function deleteSlaclienteAlert($rows)
    {
        $slaclienteAlertRepository = InstanceProvider::getRepository()->getSlaclienteAlert();
        try {
            foreach ($rows as $row) {
                /** @var \Teknisa\Model\Teknisa\Entities\SlaclienteAlert $slacliente */
                $slacliente = $slaclienteAlertRepository->findOneBy(array('id' => $row['ID']));
                $this->entityManager->remove($slacliente);
            }
            $this->entityManager->flush();
        } catch(Exception $e) {
            throw new Exception($e->getMessage());
        }
    }

    /**
     * @param $cdcliente
     * @param $cdassunto
     * @param $cdgrupfase
     * @param $cdcomplexid
     * @param $idRespProdEstrut
     * @param $structureTypeId
     * @param $qthorasalert
     * @param $idantesdepois
     * @throws Exception
     */
    public function saveSlacliente($cdcliente, $cdassunto, $cdgrupfase, $cdcomplexid,
                                   $idRespProdEstrut, $structureTypeId, $qthorasalert, $idantesdepois)
    {
        $slaclienteAlertFactory = InstanceProvider::getFactory()->getSlaclienteAlert();
        try {
            $slaclienteAlert = $slaclienteAlertFactory->create($cdcliente, $cdgrupfase, $cdassunto, $cdcomplexid, $idRespProdEstrut,
                $structureTypeId, $qthorasalert, $idantesdepois, 'S');
            $this->entityManager->persist($slaclienteAlert);
            $this->entityManager->flush();
        } catch(Exception $e) {
            throw new Exception($e->getMessage());
        }
    }
}
